@@ -23,6 +23,8 @@
 
 #include <cmath>
 
+#include <KLocalizedString>
+
 using namespace Kleo;
 using namespace Kleo::Crypto;
 
@@ -115,8 +117,6 @@ void TaskCollection::Private::taskStarted()
 
 void TaskCollection::Private::calculateAndEmitProgress()
 {
-    typedef std::map<int, std::shared_ptr<Task> >::const_iterator ConstIterator;
-
     quint64 total = 0;
     quint64 processed = 0;
 
@@ -135,7 +135,7 @@ void TaskCollection::Private::calculateAndEmitProgress()
     }
 
     bool unknowable = false;
-    for (ConstIterator it = m_tasks.begin(), end = m_tasks.end(); it != end; ++it) {
+    for (auto it = m_tasks.begin(), end = m_tasks.end(); it != end; ++it) {
         // Sum up progress and totals
         const std::shared_ptr<Task> &i = it->second;
         Q_ASSERT(i);
@@ -155,7 +155,13 @@ void TaskCollection::Private::calculateAndEmitProgress()
         // Scale down to avoid range issues.
         int scaled = 1000 * (m_progress / static_cast<double>(m_totalProgress));
         qCDebug(KLEOPATRA_LOG) << "Collection Progress: " << scaled << " total: " << 1000;
-        Q_EMIT q->progress(m_lastProgressMessage, scaled, 1000);
+        if (total == processed) {
+            // This can happen when an output is finalizing, e.g. extracting an
+            // archive.
+            Q_EMIT q->progress(i18n("Finalizing output..."), 0, 0);
+        } else {
+            Q_EMIT q->progress(m_lastProgressMessage, scaled, 1000);
+        }
     } else {
         if (total < processed) {
             qCDebug(KLEOPATRA_LOG) << "Total progress is smaller then current progress.";
@@ -190,16 +196,15 @@ bool TaskCollection::allTasksHaveErrors() const
 
 std::shared_ptr<Task> TaskCollection::taskById(int id) const
 {
-    const std::map<int, std::shared_ptr<Task> >::const_iterator it = d->m_tasks.find(id);
+    const auto it = d->m_tasks.find(id);
     return it != d->m_tasks.end() ? it->second : std::shared_ptr<Task>();
 }
 
 std::vector<std::shared_ptr<Task> > TaskCollection::tasks() const
 {
-    typedef std::map<int, std::shared_ptr<Task> >::const_iterator ConstIterator;
     std::vector<std::shared_ptr<Task> > res;
     res.reserve(d->m_tasks.size());
-    for (ConstIterator it = d->m_tasks.begin(), end = d->m_tasks.end(); it != end; ++it) {
+    for (auto it = d->m_tasks.begin(), end = d->m_tasks.end(); it != end; ++it) {
         res.push_back(it->second);
     }
     return res;
