@@ -11,6 +11,8 @@
 
 #include "certifywidget.h"
 
+#include <utils/accessibility.h>
+
 #include "kleopatra_debug.h"
 
 #include <KLocalizedString>
@@ -48,11 +50,6 @@
 
 #include <gpgme++/key.h>
 
-#include <gpgme++/gpgmepp_version.h>
-#if GPGMEPP_VERSION >= 0x10E00 // 1.14.0
-# define GPGME_HAS_REMARKS
-#endif
-
 using namespace Kleo;
 
 namespace {
@@ -72,7 +69,7 @@ private:
     QToolButton toggleButton;
     QFrame headerLine;
     QParallelAnimationGroup toggleAnimation;
-    QScrollArea contentArea;
+    QWidget contentArea;
     int animationDuration{300};
 };
 
@@ -90,7 +87,6 @@ AnimatedExpander::AnimatedExpander(const QString &title, QWidget *parent):
     headerLine.setFrameShadow(QFrame::Sunken);
     headerLine.setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
 
-    contentArea.setStyleSheet(QStringLiteral("QScrollArea { border: none; }"));
     contentArea.setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
 
     // start out collapsed
@@ -188,7 +184,7 @@ public:
         int i = 0;
         for (const auto &uid: key.userIDs()) {
             if (uid.isRevoked() || uid.isInvalid()) {
-                // Skip user ID's that cannot really be certified.
+                // Skip user IDs that cannot really be certified.
                 i++;
                 continue;
             }
@@ -248,14 +244,13 @@ auto createInfoButton(const QString &text, QWidget *parent)
     infoBtn->setFlat(true);
 
     QObject::connect(infoBtn, &QPushButton::clicked, infoBtn, [infoBtn, text] () {
-        QToolTip::showText(infoBtn->mapToGlobal(QPoint()) + QPoint(infoBtn->width(), 0),
-                           text, infoBtn, QRect(), 30000);
+        const auto pos = infoBtn->mapToGlobal(QPoint()) + QPoint(infoBtn->width(), 0);
+        showToolTip(pos, text, infoBtn);
     });
 
     return infoBtn;
 }
 
-#ifdef QGPGME_SUPPORTS_SIGNATURE_EXPIRATION
 QString dateFormatWithFourDigitYear(QLocale::FormatType format)
 {
     // Force the year to be formatted as four digit number, so that
@@ -269,7 +264,6 @@ QString formatDate(const QDate &date, QLocale::FormatType format)
 {
     return QLocale{}.toString(date, dateFormatWithFourDigitYear(format));
 }
-#endif
 
 }
 
@@ -278,29 +272,23 @@ class CertifyWidget::Private
 public:
     Private(CertifyWidget *qq)
         : q{qq}
-        , mFprLabel{new QLabel{q}}
-        , mSecKeySelect{new KeySelectionCombo{/* secretOnly= */true, q}}
-        , mMissingOwnerTrustInfo{new KMessageWidget{q}}
-        , mExportCB{new QCheckBox{q}}
-        , mPublishCB{new QCheckBox{q}}
-        , mTagsLE{new QLineEdit{q}}
-        , mTrustSignatureCB{new QCheckBox{q}}
-        , mTrustSignatureDomainLE{new QLineEdit{q}}
-        , mExpirationCheckBox{new QCheckBox{q}}
-        , mExpirationDateEdit{new KDateComboBox{q}}
-        , mSetOwnerTrustAction{new QAction{q}}
     {
         auto mainLay = new QVBoxLayout{q};
+
+        mFprLabel = new QLabel{q};
         mainLay->addWidget(mFprLabel);
 
-        auto secKeyLay = new QHBoxLayout{q};
+        auto secKeyLay = new QHBoxLayout;
         secKeyLay->addWidget(new QLabel(i18n("Certify with:")));
 
+        mSecKeySelect = new KeySelectionCombo{/* secretOnly= */true, q};
         mSecKeySelect->setKeyFilter(std::make_shared<SecKeyFilter>());
 
         secKeyLay->addWidget(mSecKeySelect, 1);
         mainLay->addLayout(secKeyLay);
 
+        mMissingOwnerTrustInfo = new KMessageWidget{q};
+        mSetOwnerTrustAction = new QAction{q};
         mSetOwnerTrustAction->setText(i18nc("@action:button", "Set Owner Trust"));
         mSetOwnerTrustAction->setToolTip(QLatin1String("<html>") +
                                          i18nc("@info:tooltip",
@@ -323,14 +311,16 @@ public:
         auto expander = new AnimatedExpander{i18n("Advanced"), q};
         mainLay->addWidget(expander);
 
-        auto advLay = new QVBoxLayout{q};
+        auto advLay = new QVBoxLayout;
 
+        mExportCB = new QCheckBox{q};
         mExportCB->setText(i18n("Certify for everyone to see (exportable)"));
         advLay->addWidget(mExportCB);
 
         {
-            auto layout = new QHBoxLayout{q};
+            auto layout = new QHBoxLayout;
 
+            mPublishCB = new QCheckBox{q};
             mPublishCB->setText(i18n("Publish on keyserver afterwards"));
             mPublishCB->setEnabled(mExportCB->isChecked());
 
@@ -340,18 +330,17 @@ public:
             advLay->addLayout(layout);
         }
 
-#ifndef GPGME_HAS_REMARKS
-        mTagsLE->setVisible(false);
-#else
         {
-            auto tagsLay = new QHBoxLayout{q};
+            auto tagsLay = new QHBoxLayout;
 
+            mTagsLE = new QLineEdit{q};
             mTagsLE->setPlaceholderText(i18n("Tags"));
             auto infoBtn = createInfoButton(i18n("You can use this to add additional info to a certification.") +
                                             QStringLiteral("<br/><br/>") +
                                             i18n("Tags created by anyone with full certification trust "
                                                 "are shown in the keylist and can be searched."),
                                             q);
+            infoBtn->setAccessibleName(i18n("Explain tags"));
 
             tagsLay->addWidget(new QLabel{i18n("Tags:"), q});
             tagsLay->addWidget(mTagsLE, 1);
@@ -359,20 +348,17 @@ public:
 
             advLay->addLayout(tagsLay);
         }
-#endif
 
-#ifndef QGPGME_SUPPORTS_SIGNATURE_EXPIRATION
-        mExpirationCheckBox->setVisible(false);
-        mExpirationDateEdit->setVisible(false);
-#else
         {
-            auto layout = new QHBoxLayout{q};
+            auto layout = new QHBoxLayout;
 
+            mExpirationCheckBox = new QCheckBox{q};
             mExpirationCheckBox->setText(i18n("Expiration:"));
 
+            mExpirationDateEdit = new KDateComboBox{q};
             mExpirationDateEdit->setOptions(KDateComboBox::EditDate | KDateComboBox::SelectDate | KDateComboBox::DatePicker |
                                             KDateComboBox::DateKeywords | KDateComboBox::WarnOnInvalid);
-            static const QDate maxAllowedDate{2106, 2, 6};
+            static const QDate maxAllowedDate{2106, 2, 5};
             const QDate today = QDate::currentDate();
             mExpirationDateEdit->setDateRange(today.addDays(1), maxAllowedDate,
                                               i18n("The certification must be valid at least until tomorrow."),
@@ -391,6 +377,7 @@ public:
                                                  "your certification to a certain amount of time. Once the expiration "
                                                  "date has passed, your certification is no longer valid."),
                                             q);
+            infoBtn->setAccessibleName(i18n("Explain expiration"));
 
             layout->addWidget(mExpirationCheckBox);
             layout->addWidget(mExpirationDateEdit, 1);
@@ -398,15 +385,11 @@ public:
 
             advLay->addLayout(layout);
         }
-#endif
 
-#ifndef QGPGME_SUPPORTS_TRUST_SIGNATURES
-        mTrustSignatureCB->setVisible(false);
-        mTrustSignatureDomainLE->setVisible(false);
-#else
         {
-            auto layout = new QHBoxLayout{q};
+            auto layout = new QHBoxLayout;
 
+            mTrustSignatureCB = new QCheckBox{q};
             mTrustSignatureCB->setText(i18n("Certify as trusted introducer"));
             auto infoBtn = createInfoButton(i18n("You can use this to certify a trusted introducer for a domain.") +
                                             QStringLiteral("<br/><br/>") +
@@ -415,6 +398,7 @@ public:
                                                  "as certified, i.e. a trusted introducer acts as a kind of "
                                                  "intermediate CA for a domain."),
                                             q);
+            infoBtn->setAccessibleName(i18n("Explain trusted introducer"));
 
             layout->addWidget(mTrustSignatureCB, 1);
             layout->addWidget(infoBtn);
@@ -422,8 +406,9 @@ public:
             advLay->addLayout(layout);
         }
         {
-            auto layout = new QHBoxLayout{q};
+            auto layout = new QHBoxLayout;
 
+            mTrustSignatureDomainLE = new QLineEdit{q};
             mTrustSignatureDomainLE->setPlaceholderText(i18n("Domain"));
             mTrustSignatureDomainLE->setEnabled(mTrustSignatureCB->isChecked());
 
@@ -432,7 +417,6 @@ public:
 
             advLay->addLayout(layout);
         }
-#endif
 
         expander->setContentLayout(advLay);
 
@@ -443,9 +427,7 @@ public:
         });
 
         connect(mSecKeySelect, &KeySelectionCombo::currentKeyChanged, [this] (const GpgME::Key &) {
-#ifdef GPGME_HAS_REMARKS
             updateTags();
-#endif
             checkOwnerTrust();
             Q_EMIT q->changed();
         });
@@ -480,7 +462,6 @@ public:
         if (mTagsLE->isModified()) {
             return;
         }
-#ifdef GPGME_HAS_REMARKS
         GpgME::Key remarkKey = mSecKeySelect->currentKey();
 
         if (!remarkKey.isNull()) {
@@ -492,20 +473,19 @@ public:
                 if (c_remark) {
                     const QString candidate = QString::fromUtf8(c_remark);
                     if (candidate != remark) {
-                        qCDebug(KLEOPATRA_LOG) << "Different remarks on user ids. Taking last.";
+                        qCDebug(KLEOPATRA_LOG) << "Different remarks on user IDs. Taking last.";
                         remark = candidate;
                         uidsWithRemark.clear();
                     }
                     uidsWithRemark.push_back(uid);
                 }
             }
-            // Only select the user ids with the correct remark
+            // Only select the user IDs with the correct remark
             if (!remark.isEmpty()) {
                 selectUserIDs(uidsWithRemark);
             }
             mTagsLE->setText(remark);
         }
-#endif
     }
 
     void updateTrustSignatureDomain()
@@ -595,7 +575,7 @@ public:
         if (mTarget.isNull() || mSecKeySelect->currentKey().isNull()) {
             return false;
         }
-        // do not accept empty list of user ids
+        // do not accept empty list of user IDs
         if (selectedUserIDs().empty()) {
             return false;
         }
