@@ -1,4 +1,4 @@
-/*  view/smartcardwidget.h
+/*  view/welcomewidget.cpp
 
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2017 Bundesamt für Sicherheit in der Informationstechnik
@@ -7,8 +7,12 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include <config-kleopatra.h>
+
 #include "welcomewidget.h"
 
+#include "htmllabel.h"
+
 #include <version-kleopatra.h>
 #include <Libkleo/GnuPG>
 
@@ -59,9 +63,10 @@ public:
                                       "https://en.wikipedia.org/wiki/Public-key_cryptography");
         const QString learnMore = i18nc("%1 is link a wiki article", "You can learn more about this on <a href=\"%1\">Wikipedia</a>.", wikiUrl);
 
-        auto label = new QLabel(templ.arg(welcome).arg(introduction).arg(keyExplanation).arg(privateKeyExplanation).arg(publicKeyExplanation).arg(learnMore));
-        label->setTextInteractionFlags(Qt::TextBrowserInteraction);
-        label->setOpenExternalLinks(true);
+        const auto labelText = templ.arg(welcome).arg(introduction).arg(keyExplanation).arg(privateKeyExplanation).arg(publicKeyExplanation).arg(learnMore);
+        mLabel = new HtmlLabel{labelText, q};
+        mLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
+        mLabel->setOpenExternalLinks(true);
 
         auto genKeyAction = new QAction(q);
         genKeyAction->setText(i18n("New Key Pair..."));
@@ -74,7 +79,7 @@ public:
         connect(importAction, &QAction::triggered, q, [this] () { import(); });
         connect(genKeyAction, &QAction::triggered, q, [this] () { generate(); });
 
-        mGenerateBtn = new QToolButton();
+        mGenerateBtn = new QToolButton{q};
         mGenerateBtn->setDefaultAction(genKeyAction);
         mGenerateBtn->setIconSize(QSize(64, 64));
         mGenerateBtn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
@@ -84,7 +89,7 @@ public:
         KConfigGroup restrictions(KSharedConfig::openConfig(), "KDE Action Restrictions");
         mGenerateBtn->setEnabled(restrictions.readEntry("action/file_new_certificate", true));
 
-        mImportBtn = new QToolButton();
+        mImportBtn = new QToolButton{q};
         mImportBtn->setDefaultAction(importAction);
         mImportBtn->setIconSize(QSize(64, 64));
         mImportBtn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
@@ -104,7 +109,7 @@ public:
         vLay->addStretch(-1);
 
         hLay->addStretch(-1);
-        hLay->addWidget(label);
+        hLay->addWidget(mLabel);
         hLay->addStretch(-1);
     }
 
@@ -136,8 +141,9 @@ public:
     }
 
     WelcomeWidget *const q;
-    QToolButton *mGenerateBtn;
-    QToolButton *mImportBtn;
+    HtmlLabel *mLabel = nullptr;
+    QToolButton *mGenerateBtn = nullptr;
+    QToolButton *mImportBtn = nullptr;
 };
 
 
@@ -145,3 +151,8 @@ WelcomeWidget::WelcomeWidget (QWidget *parent): QWidget(parent),
     d(new Private(this))
 {
 }
+
+void WelcomeWidget::focusFirstChild(Qt::FocusReason reason)
+{
+    d->mLabel->setFocus(reason);
+}
